pub struct LogupTableOutput<F> {
pub eval_claim: F,
pub pushforward_claim: F,
pub index_eval_claims: Vec<F>,
}Expand description
The reduced claims belonging to one table.
Fields
eval_claim: FThe claimed evaluation of the table multilinear T at its prefix of
LogupOutput::table_eval_point.
pushforward_claim: FThe claimed evaluation of the pushforward multilinear Y at the same prefix.
index_eval_claims: Vec<F>The claimed evaluations of this table’s lookers’ index multilinears I, in its own looker
order, each at that looker’s own suffix of LogupOutput::index_eval_point.