pub struct TableLookup<'a, Elem> {
pub n_vars: usize,
pub lookers: Vec<LookerClaim<'a, Elem>>,
}Expand description
One table together with the lookers that read it.
Fields
n_vars: usizeThe number of variables m of this table’s multilinear (2^m entries).
lookers: Vec<LookerClaim<'a, Elem>>The claims of the lookers that read this table. Their evaluation points may differ in length, both from each other and from the table.